#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_CGOLD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_CGOLD_HPP_INCLUDED

#include <boost/simd/constant/include/constants/cgold.hpp>

#endif
